@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import json
 
 from django.apps import apps
@@ -15,7 +13,7 @@ class Command(BaseRevisionCommand):
     help = "Creates initial revisions for a given app [and model]."
 
     def add_arguments(self, parser):
-        super(Command, self).add_arguments(parser)
+        super().add_arguments(parser)
         parser.add_argument(
             "--comment",
             action="store",
